@@ -107,6 +107,11 @@ MainWindow::MainWindow()
     // settings from kcfg values
     updateTrainingPhraseFont();
 
+    // create training profile if none exists:
+    if (!m_profileManager->activeProfile()) {
+        m_profileManager->addProfile("Unnamed Identity"); //TODO use i18n for 4.14
+    }
+
     // set initial view
     m_view->rootObject()->setProperty("viewMode", Trainer);
 
@@ -235,6 +240,13 @@ void MainWindow::downloadNewStuff()
         //update available courses
         m_resourceManager->loadCourseResources();
 
+        if (!m_profileManager->activeProfile()) {
+            kWarning() << "Not registering course language for favorite languages:"
+                << " no active learner profile set";
+            delete dialog;
+            return;
+        }
+
         // add languages of new courses to favorite languages
         foreach (const KNS3::Entry &entry, dialog->changedEntries()) {
             foreach (const QString &path, entry.installedFiles()) {
